import { render, screen } from '@testing-library/react';
import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { chemicalsFixture } from '@/models/fixtures/chemicalsFixture';
import { Accordion } from '@/shared/Accordion';
import { ChemicalsAccordion } from './ChemicalsAccordion.component';

const renderComponent = (initialStoreState: InitialStoreState = {}): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <Accordion>
          <ChemicalsAccordion />
        </Accordion>
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('DrugsAccordion - component', () => {
  it('should display drugs number after succesfull chemicals search', () => {
    renderComponent({
      chemicals: { data: chemicalsFixture, loading: 'succeeded', error: { name: '', message: '' } },
    });
    expect(screen.getByText('Chemicals (2)')).toBeInTheDocument();
  });
  it('should display loading indicator while waiting for chemicals search response', () => {
    renderComponent({
      chemicals: { data: [], loading: 'pending', error: { name: '', message: '' } },
    });
    expect(screen.getByText('Chemicals (Loading...)')).toBeInTheDocument();
  });
});
