import { render, screen } from '@testing-library/react';
import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { mirnasFixture } from '@/models/fixtures/mirnasFixture';
import { Accordion } from '@/shared/Accordion';
import { MirnaAccordion } from './MirnaAccordion.component';

const renderComponent = (initialStoreState: InitialStoreState = {}): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <Accordion>
          <MirnaAccordion />
        </Accordion>
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('DrugsAccordion - component', () => {
  it('should display drugs number after succesfull chemicals search', () => {
    renderComponent({
      mirnas: { data: mirnasFixture, loading: 'succeeded', error: { name: '', message: '' } },
    });
    expect(screen.getByText('MiRNA (2)')).toBeInTheDocument();
  });
  it('should display loading indicator while waiting for chemicals search response', () => {
    renderComponent({
      mirnas: { data: [], loading: 'pending', error: { name: '', message: '' } },
    });
    expect(screen.getByText('MiRNA (Loading...)')).toBeInTheDocument();
  });
});
